@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013-2020, PyInstaller Development Team.
+# Copyright (c) 2013-2021, PyInstaller Development Team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -9,12 +9,10 @@
 # SPDX-License-Identifier: Apache-2.0
 #-----------------------------------------------------------------------------
 
-# Starting with Python 3.8, win32api failed with "ImportError: DLL load failed
-# while importing win32clipboard: The specified module could not be found."
-# This seems to be caused by pywintypes.dll not being found in various
-# situations.
+# Starting with Python 3.8, win32api failed with "ImportError: DLL load failed while importing win32clipboard: The
+# specified module could not be found." This seems to be caused by pywintypes.dll not being found in various situations.
 # See https://github.com/mhammond/pywin32/pull/1430 and
 # https://github.com/mhammond/pywin32/commit/71afa71e11e6631be611ca5cb57cda526
 # As a work-around, import pywintypes prior to win32api.
 
-import pywintypes
+import pywintypes  # noqa: F401
